"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenericNpmPackageManager = void 0;
const error_1 = require("../error");
class GenericNpmPackageManager {
    constructor(executor, opts) {
        this.executor = executor;
        this.opts = opts;
    }
    async runScript(manifest) {
        if (!manifest) {
            throw new TypeError('(runScript) "manifest" arg is required');
        }
        const { script, packedPkg } = manifest;
        const args = ['run', script];
        const { pkgName, installPath: cwd } = packedPkg;
        let result;
        try {
            const rawResult = await this.executor.exec(args, {
                cwd,
            });
            result = { pkgName, script, rawResult, cwd };
        }
        catch (err) {
            const error = err;
            result = {
                pkgName,
                script,
                rawResult: error,
                cwd,
            };
            if (this.opts.loose && /missing script:/i.test(error.stderr)) {
                result.skipped = true;
            }
            else {
                result.error = new error_1.SmokerError(`(runScript) Script "${script}" in package "${pkgName}" failed: ${error.message}`);
            }
        }
        if (!result.error && !result.skipped && result.rawResult.failed) {
            if (result.rawResult.stderr &&
                /missing script:/i.test(result.rawResult.stderr)) {
                if (!this.opts.loose) {
                    result.error = new error_1.SmokerError(`(runScript) Script "${script}" in package "${pkgName}" failed; script not found`);
                }
                else {
                    result.skipped = true;
                }
            }
            else {
                let message;
                if (result.rawResult.exitCode) {
                    message = `(runScript) Script "${script}" in package "${pkgName}" failed with exit code ${result.rawResult.exitCode}: ${result.rawResult.all}`;
                }
                else {
                    message = `(runScript) Script "${script}" in package "${pkgName}" failed: ${result.rawResult.all}`;
                }
                result.error = new error_1.SmokerError(message);
            }
        }
        if (result.error) {
            this.debug(`(runScripts) Script "%s" in package "%s" failed; continuing...`, script, pkgName);
        }
        else {
            this.debug('(runScripts) Successfully executed script %s in package %s', script, pkgName);
        }
        return result;
    }
}
exports.GenericNpmPackageManager = GenericNpmPackageManager;
//# sourceMappingURL=npm.js.map