"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Npm9 = void 0;
const debug_1 = __importDefault(require("debug"));
const error_1 = require("../error");
const npm7_1 = require("./npm7");
class Npm9 extends npm7_1.Npm7 {
    constructor(executor, opts) {
        super(executor, opts);
        this.name = 'npm';
        this.debug = (0, debug_1.default)(`midnight-smoker:pm:npm9`);
    }
    static accepts(semver) {
        return Boolean(~semver.compare('9.0.0'));
    }
    static load(executor, opts) {
        return new npm7_1.Npm7(executor, opts);
    }
    async install(manifest) {
        const { packedPkgs, tarballRootDir } = manifest;
        if (!packedPkgs?.length) {
            throw new TypeError('(install) Non-empty "packedPkgs" arg is required');
        }
        const additionalDeps = manifest.additionalDeps ?? [];
        // otherwise we get a deprecation warning
        const installArgs = [
            'install',
            '--no-package-lock',
            '--install-strategy=shallow',
            ...packedPkgs.map(({ tarballFilepath }) => tarballFilepath),
            ...additionalDeps,
        ];
        let installResult;
        try {
            installResult = await this.executor.exec(installArgs, {
                cwd: tarballRootDir,
            });
        }
        catch (err) {
            throw new error_1.SmokerError(`(install) ${this.name} failed to spawn: ${err.message}`);
        }
        if (installResult.exitCode) {
            this.debug('(install) Failed: %O', installResult);
            throw new error_1.SmokerError(`(install) Installation failed with exit code ${installResult.exitCode}: ${installResult.stderr}`);
        }
        this.debug('(install) Installed %d packages', packedPkgs.length);
        return installResult;
    }
}
exports.Npm9 = Npm9;
Npm9.bin = 'npm';
exports.default = Npm9;
//# sourceMappingURL=npm9.js.map