"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_RULE_CONFIG = exports.RuleConfigSchema = void 0;
const zod_1 = require("zod");
const no_banned_files_1 = __importDefault(require("./builtin/no-banned-files"));
const no_missing_entry_point_1 = __importDefault(require("./builtin/no-missing-entry-point"));
const no_missing_exports_1 = __importDefault(require("./builtin/no-missing-exports"));
const no_missing_pkg_files_1 = __importDefault(require("./builtin/no-missing-pkg-files"));
const severity_1 = require("./severity");
const BaseRuleConfigSchema = zod_1.z.object({
    [no_banned_files_1.default.name]: no_banned_files_1.default.ruleSchema,
    [no_missing_pkg_files_1.default.name]: no_missing_pkg_files_1.default.ruleSchema,
    [no_missing_entry_point_1.default.name]: no_missing_entry_point_1.default.ruleSchema,
    [no_missing_exports_1.default.name]: no_missing_exports_1.default.ruleSchema,
});
exports.RuleConfigSchema = BaseRuleConfigSchema.transform((val) => ({
    ...val,
    getEnabledRules: () => new Set(Object.entries(val)
        .filter(([, severity]) => severity !== severity_1.RuleSeverities.OFF)
        .map(([ruleName]) => ruleName)),
    isRuleEnabled: (ruleName) => {
        const name = ruleName;
        return (name in BaseRuleConfigSchema.shape && val[name] !== severity_1.RuleSeverities.OFF);
    },
}));
exports.DEFAULT_RULE_CONFIG = {
    [no_missing_pkg_files_1.default.name]: no_missing_pkg_files_1.default.defaultSeverity,
    [no_banned_files_1.default.name]: no_banned_files_1.default.defaultSeverity,
    [no_missing_entry_point_1.default.name]: no_missing_entry_point_1.default.defaultSeverity,
    [no_missing_exports_1.default.name]: no_missing_exports_1.default.defaultSeverity,
};
//# sourceMappingURL=rule-config.js.map